@@ -8,3 +8,11 @@
 # uted under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES
 # OR CONDITIONS OF ANY KIND, either express or implied.  See the License for
 # specific language governing permissions and limitations under the License.
+
+print """
+Sorry!  I haven't gotten the okay to release q.py yet, but this
+formality will be taken care of soon.  Please try installing it
+again in a day or two.
+
+-- @zestyping
+"""
